@@ -15,6 +15,8 @@ def update_data_info():
     """
     os.system("bash {x}/sapera/scraper/updater.sh {x}".format(
         x=BASE_DIR))  # calling the updater.sh
+    with open(BASE_DIR + "/sapera/scraper/status.txt", "r") as status:
+        print(status.read())
 
 
 def download_data():
@@ -25,7 +27,6 @@ def download_data():
     :return:
     """
     pass
-    # Work in Progress
 
 
 def random_generator():
